@@ -17,9 +17,9 @@
  * along with QCAD.
  */
 
-include("EAction.js");
-include("Select/Select.js");
-include("Widgets/CadToolBar/CadToolBar.js");
+include("scripts/EAction.js");
+include("scripts/Select/Select.js");
+include("scripts/Widgets/CadToolBar/CadToolBar.js");
 
 /**
  * \class DefaultAction
@@ -80,6 +80,7 @@ DefaultAction.prototype.setState = function(state) {
         this.setArrowCursor();
     }
 
+    var tr;
     switch (this.state) {
     case DefaultAction.State.Neutral:
         this.d1Model = RVector.invalid;
@@ -99,21 +100,23 @@ DefaultAction.prototype.setState = function(state) {
         this.d2Screen = RVector.invalid;
         break;
     case DefaultAction.State.SettingCorner2:
-        this.setLeftMouseTip(qsTr("Set second corner"));
+        tr = qsTr("Second corner");
+        this.setLeftMouseTip(tr);
+        this.setCommandPrompt(tr);
         this.setRightMouseTip("");
         break;
     case DefaultAction.State.MovingReference:
     case DefaultAction.State.SettingReference:
-        this.setLeftMouseTip(
-                qsTr("Specify target point of reference point")
-        );
+        tr = qsTr("Target point of reference point");
+        this.setLeftMouseTip(tr);
+        this.setCommandPrompt(tr);
         this.setRightMouseTip("");
         break;
     case DefaultAction.State.MovingEntity:
     case DefaultAction.State.SettingEntity:
-        this.setLeftMouseTip(
-                qsTr("Specify target point of selection")
-        );
+        tr = qsTr("Target point of selection");
+        this.setLeftMouseTip(tr);
+        this.setCommandPrompt(tr);
         this.setRightMouseTip("");
         break;
     case DefaultAction.State.MovingEntityInBlock:
@@ -137,13 +140,20 @@ DefaultAction.prototype.resumeEvent = function() {
 };
 
 DefaultAction.prototype.mouseMoveEvent = function(event) {
-    // we're in the middle of panning: don't do anything:
+    // we're in the middle of panning:
+    // do nothing:
     if (event.buttons().valueOf() === Qt.MidButton.valueOf() ||
         (event.buttons().valueOf() === Qt.LeftButton.valueOf() &&
          event.modifiers().valueOf() === Qt.ControlModifier.valueOf())) {
         return;
     }
 
+    // we're in the middle of choosing something from a context menu:
+    // do nothing:
+    if (this.waitingForContextMenu) {
+        return;
+    }
+
     var view, referencePoint, entityId, range;
     
     if (isNull(this.pickRangePixels)) {
@@ -275,11 +285,16 @@ DefaultAction.prototype.mouseMoveEvent = function(event) {
 };
 
 DefaultAction.prototype.mouseReleaseEvent = function(event) {
+    if (this.waitingForContextMenu) {
+        return;
+    }
+
     var persistentSelection = RSettings.getBoolValue("GraphicsView/PersistentSelection", false);
     var entityId;
 
-    var shiftPressed = this.isShiftPressed(event) || (event.modifiers() & Qt.ControlModifier) > 0 || persistentSelection===true;
-    var addToSelection = this.getAddToSelection(shiftPressed);
+    var shiftPressed = isShiftPressed(event);
+    var controlPressed = isControlPressed(event);
+    var addToSelection = this.getAddToSelection(shiftPressed) || controlPressed || persistentSelection===true;
 
     if (event.button() === Qt.LeftButton) {
         switch (this.state) {
@@ -301,7 +316,6 @@ DefaultAction.prototype.mouseReleaseEvent = function(event) {
                 }
             }
 
-
             // find selectable entity under cursor:
             entityId = this.getEntityId(event, false, true);
 
@@ -330,17 +344,9 @@ DefaultAction.prototype.mouseReleaseEvent = function(event) {
             this.di.clearPreview();
             this.d2Model = event.getModelPosition();
 
-            if (addToSelection ||
-                (event.modifiers().valueOf() == Qt.ControlModifier.valueOf()) ||
-                persistentSelection===true) {
+            // select entities:
+            this.di.selectBoxXY(new RBox(this.d1Model, this.d2Model), addToSelection);
 
-                // add all entities in window to the selection:
-                this.di.selectBoxXY(new RBox(this.d1Model, this.d2Model), true);
-            } else {
-                // select entities in window only:
-                this.di.selectBoxXY(new RBox(this.d1Model, this.d2Model), false);
-            }
-            // event.setConsumed(true);
             this.setState(DefaultAction.State.Neutral);
             break;
 
@@ -455,7 +461,7 @@ DefaultAction.prototype.escapeEvent = function(event) {
 DefaultAction.prototype.pickCoordinate = function(event, preview) {
     var op;
 
-    var shiftPressed = this.isShiftPressed(event);
+    var shiftPressed = isShiftPressed(event);
     var addToSelection = this.getAddToSelection(shiftPressed);
     var doc = this.getDocument();
 
@@ -485,7 +491,9 @@ DefaultAction.prototype.pickCoordinate = function(event, preview) {
 
         if (preview) {
             this.d2Model = d2;
-            op = new RMoveReferencePointOperation(this.d1Model, this.d2Model);
+            op = new RMoveReferencePointOperation(this.d1Model, this.d2Model, event.getModifiers());
+            var scene = this.di.getGraphicsSceneWithFocus();
+            op.setGraphicsScene(scene);
             this.di.previewOperation(op);
         }
         else {
@@ -494,7 +502,9 @@ DefaultAction.prototype.pickCoordinate = function(event, preview) {
             }
             else {
                 this.d2Model = d2;
-                op = new RMoveReferencePointOperation(this.d1Model, this.d2Model);
+                op = new RMoveReferencePointOperation(this.d1Model, this.d2Model, event.getModifiers());
+                var scene = this.di.getGraphicsSceneWithFocus();
+                op.setGraphicsScene(scene);
                 op.setText(qsTr("Move Reference Point"));
                 this.di.applyOperation(op);
                 this.di.clearPreview();
@@ -690,7 +700,7 @@ DefaultAction.prototype.entityDoubleClicked = function(entityId, event) {
         if (RSettings.getBoolValue("GraphicsView/DoubleClickSelectContour", true)===true) {
             include("scripts/Select/SelectContour/SelectContour.js");
             var matchingEntityIds = SelectContour.getConnectedEntities(this.document, entityId, 0.001);
-            var add = this.isShiftPressed(event);
+            var add = isShiftPressed(event);
             if (entity.isSelected()) {
                 this.di.selectEntities(matchingEntityIds, add);
             }
@@ -706,19 +716,6 @@ DefaultAction.prototype.entityDoubleClicked = function(entityId, event) {
 //    }
 };
 
-/**
- * \return True if the shift key is pressed to alter the function (e.g. add to selection).
- */
-DefaultAction.prototype.isShiftPressed = function(event) {
-    if (isFunction(event.getModifiers)) {
-        return (event.getModifiers() & Qt.ShiftModifier) > 0;
-    }
-    if (isFunction(event.modifiers)) {
-        return (event.modifiers().valueOf() === Qt.ShiftModifier.valueOf());
-    }
-    return false;
-};
-
 /**
  * \return True to add to selection (by default this is when shiftPressed is true).
  * May be reimplemented to allow other ways to add to selection (e.g. user interface button, etc.)
